pub struct Field {
pub name: CowStr,
pub docs: Option<CowStr>,
pub format: FieldFormat,
pub repeating: bool,
}Expand description
In-memory representation of a single
field in a DataType.
Fields
name: CowStrName of the field.
docs: Option<CowStr>Documentation for the field.
format: FieldFormatEncoding format of the field.
repeating: boolIf true, the field will be treated as a list of data with the same format as the field.