Utilities for reading and writing streams of
binary data, with optional support for std::io::Read
and std::io::Write on platforms supporting them.
Enums
- Enumeration of errors that may occur while reading and/or writing streams of data.
Traits
- A thing that reads from a stream of bytes.
- A thing that writes to a stream of bytes.