Enum pact::stream::StreamError
source · pub enum StreamError {
Empty,
Closed,
Other {
error: Text,
},
}Expand description
Enumeration of errors that may occur while reading and/or writing streams of data.
Variants
Empty
The stream is empty and will not receive any more data.
Closed
The stream is closed and will not receive or accept any more data.
Other
Uncategorized error.